@@ -3,6 +3,7 @@ package Pcore::App::Controller::ExtJS;
 use Pcore -role;
 use Pcore::Util::Data qw[to_json];
 use Pcore::ExtJS;
+use JavaScript::Packer qw[];
 
 with qw[Pcore::App::Controller];
 
@@ -15,6 +16,8 @@ has perl_ext_app_namespace => ( is => 'ro',   isa => Str,     init_arg => undef
 has ext_app_namespace      => ( is => 'ro',   isa => Str,     init_arg => undef );
 has ext_namespace          => ( is => 'ro',   isa => Str,     init_arg => undef );
 
+has _static_cache => ( is => 'ro', isa => HashRef, init_arg => undef );
+
 # this method can be overrided in the child class
 sub BUILD ( $self, $args ) {
     return;
@@ -48,20 +51,18 @@ around BUILD => sub ( $orig, $self, $args ) {
 
         $self->{perl_ext_app_namespace} = ref $self;
 
-        $self->{ext_app_namespace} = ref($self) =~ s/\A$app_namespace\::Index::/$app_namespace\::/smr;
-
-        $self->{ext_app_namespace} =~ s/:://smg;
-
-        $self->{ext_namespace} = $self->{ext_app_namespace};
+        $self->{ext_namespace} = $self->{ext_app_namespace} = ref($self) =~ s/:://smgr;
     }
 
     # this is ExtJS namespace class
     else {
 
-        # find ExtJS app instance
+        # find parent ExtJS app instance
         my $parent_class = ref $self;
 
         while (1) {
+
+            # remove last ::label, break loop, if no last label
             last unless $parent_class =~ s/::[^:]+\z//sm;
 
             last if $parent_class eq $app_namespace;
@@ -93,7 +94,7 @@ around BUILD => sub ( $orig, $self, $args ) {
     }
 
     # validate ExtJS class
-    die qq[ExtJS namespace "$self->{ext_namespace}" is invalid] if $self->{ext_namespace} =~ /[^A-Za-z0-9.]/smg;
+    die qq[ExtJS namespace "$self->{ext_namespace}" is invalid] if $self->{ext_namespace} =~ /[^[:alpha:]\d.]/smg;
 
     # check ext_map
     my $ext_map = $self->ext_map;
@@ -110,11 +111,6 @@ around BUILD => sub ( $orig, $self, $args ) {
             };
         }
 
-        # find real base class name
-        my $real_base_class_name = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class}->{ $ext_map->{$class}->{extend} };
-
-        die qq[ExjJS class "$ext_map->{$class}->{extend}" is not registered] if !$real_base_class_name;
-
         my $class_name = ucfirst lc $class;
 
         my $perl_class_name = ref($self) . "::$class_name";
@@ -124,17 +120,26 @@ around BUILD => sub ( $orig, $self, $args ) {
         # register perl class
         $Pcore::ExtJS::BOOTSTRAP->{classic}->{class}->{$perl_class_name} = $ext_class_name;
 
-        # get base class alias
-        if ( my $base_class_alias = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class_to_alias}->{$real_base_class_name} ) {
-            my ($alias_namespace) = ( $base_class_alias =~ /(.+)[.][^.]+\z/sm );
+        # alias
+        if ( $ext_map->{$class}->{extend} ) {
 
-            # generate alias
-            my $alias = "$alias_namespace." . ( lc $ext_class_name =~ s/[.]/-/smgr );
+            # find real base class name
+            my $real_base_class_name = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class}->{ $ext_map->{$class}->{extend} };
 
-            # register ExtJS class alias
-            $Pcore::ExtJS::BOOTSTRAP->{classic}->{class_to_alias}->{$ext_class_name} = $alias;
+            die qq[ExjJS class "$ext_map->{$class}->{extend}" is not registered] if !$real_base_class_name;
 
-            $Pcore::ExtJS::BOOTSTRAP->{classic}->{alias_to_class}->{$alias} = $ext_class_name;
+            # get base class alias
+            if ( my $base_class_alias = $Pcore::ExtJS::BOOTSTRAP->{classic}->{class_to_alias}->{$real_base_class_name} ) {
+                my ($alias_namespace) = ( $base_class_alias =~ /(.+)[.][^.]+\z/sm );
+
+                # generate alias
+                my $alias = "$alias_namespace." . ( lc $ext_class_name =~ s/[.]/-/smgr );
+
+                # register ExtJS class alias
+                $Pcore::ExtJS::BOOTSTRAP->{classic}->{class_to_alias}->{$ext_class_name} = $alias;
+
+                $Pcore::ExtJS::BOOTSTRAP->{classic}->{alias_to_class}->{$alias} = $ext_class_name;
+            }
         }
 
         # register ext class as app static class
@@ -157,9 +162,18 @@ around run => sub ( $orig, $self, $req ) {
 
         my $internal_class_name = lc $extjs_class_name;
 
-        if ( my $extend = $self->{ext_map}->{$internal_class_name}->{extend} ) {
+        if ( exists $self->{ext_map}->{$internal_class_name} ) {
             my $readable = 1;
 
+            my $is_static = $self->{ext_map}->{$internal_class_name}->{static};
+
+            # return static content from cache, if cached
+            if ( $is_static && exists $self->{_static_cache}->{$internal_class_name} ) {
+                $req->( 200, [ 'Content-Type' => 'application/javascript' ], $self->{_static_cache}->{$internal_class_name} )->finish;
+
+                return;
+            }
+
             # create ExtJS class generation context
             my $ext = bless {
                 app        => $self->{app},
@@ -167,7 +181,7 @@ around run => sub ( $orig, $self, $req ) {
                 readable   => $readable,
                 namespace  => $self,
                 class_name => $extjs_class_name,
-                extend     => $extend,
+                extend     => $self->{ext_map}->{$internal_class_name}->{extend},
                 cb         => sub ( $ext, $cfg, %args ) {
                     $ext->{cfg} = $cfg;
 
@@ -175,8 +189,18 @@ around run => sub ( $orig, $self, $req ) {
 
                     push $headers->@*, $args{headers}->@*, if $args{headers};
 
+                    my $js = $ext->to_js;
+
+                    # compress static javascript
+                    if ($is_static) {
+                        $self->minify_js($js);
+
+                        # store minified js in cache
+                        $self->{_static_cache}->{$internal_class_name} = $js;
+                    }
+
                     # generate class
-                    $req->( 200, $headers, $ext->to_js )->finish;
+                    $req->( 200, $headers, $js )->finish;
 
                     return;
                 },
@@ -198,6 +222,14 @@ around run => sub ( $orig, $self, $req ) {
     return;
 };
 
+sub minify_js ( $self, $ref ) {
+    state $js_packer = JavaScript::Packer->init;
+
+    $js_packer->minify( $ref, { compress => 'obfuscate' } );    # clean
+
+    return;
+}
+
 1;
 ## -----SOURCE FILTER LOG BEGIN-----
 ##
@@ -205,7 +237,7 @@ around run => sub ( $orig, $self, $req ) {
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    1 | 96                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([^A-Za-z] vs. [[:^alpha:]])       |
+## |    3 | 1                    | Modules::ProhibitExcessMainComplexity - Main code has high complexity score (24)                               |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
