@@ -6,7 +6,6 @@ use Pcore::Util::Data qw[to_json];
 use Pcore::ExtJS;
 use Pcore::Share::WWW;
 use WWW::CDN;
-use JavaScript::Packer qw[];
 
 with qw[Pcore::App::Controller::ExtJS];
 
@@ -127,7 +126,7 @@ sub _get_static_content ( $self, $cb ) {
         $self->{staic_content} = \join ';', $static_content->@*, '';
 
         # compress javascript
-        $js_packer->minify( $self->{staic_content}, { compress => 'obfuscate' } );    # clean
+        $self->minify_js( $self->{staic_content} );
 
         $cb->( $self->{staic_content} );
 
@@ -205,11 +204,11 @@ sub _generate_static_class ( $self, $extjs_class_name, $preloaded_classes, $cb )
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ## | Sev. | Lines                | Policy                                                                                                         |
 ## |======+======================+================================================================================================================|
-## |    3 | 161                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
+## |    3 | 160                  | Subroutines::ProhibitManyArgs - Too many arguments                                                             |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 127                  | ValuesAndExpressions::ProhibitEmptyQuotes - Quotes used with a string containing no non-whitespace characters  |
+## |    2 | 126                  | ValuesAndExpressions::ProhibitEmptyQuotes - Quotes used with a string containing no non-whitespace characters  |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    1 | 47                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([a-z] vs. [[:lower:]])            |
+## |    1 | 46                   | RegularExpressions::ProhibitEnumeratedClasses - Use named character classes ([a-z] vs. [[:lower:]])            |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
