@@ -1,4 +1,4 @@
-package Pcore::ExtJS v0.10.1;
+package Pcore::ExtJS v0.11.0;
 
 use Pcore -dist, -class;
 use Pcore::ExtJS::Raw;
@@ -20,9 +20,9 @@ use overload    #
 
 has req       => ( is => 'ro', isa => InstanceOf ['Pcore::HTTP::Server::Request'],  required => 1 );
 has namespace => ( is => 'ro', isa => ConsumerOf ['Pcore::App::Controller::ExtJS'], required => 1 );
-has class_name => ( is => 'ro', isa => Str,     required => 1 );
-has extend     => ( is => 'ro', isa => Str,     required => 1 );
-has cb         => ( is => 'ro', isa => CodeRef, required => 1 );
+has class_name => ( is => 'ro', isa => Str, required => 1 );
+has extend => ( is => 'ro', isa => Maybe [Str], required => 1 );
+has cb => ( is => 'ro', isa => CodeRef, required => 1 );
 
 has readable => ( is => 'ro', isa => Bool, default => 0 );    # generate readable JSON
 
@@ -210,7 +210,7 @@ sub to_js ( $self ) {
     my $cfg = $self->{cfg};
 
     # add "extend" property
-    $cfg->{extend} = $self->ext_class( $self->{extend} );
+    $cfg->{extend} = $self->ext_class( $self->{extend} ) if $self->{extend};
 
     # create "requires" property
     for my $require ( sort keys $self->{requires}->%* ) {
@@ -222,8 +222,6 @@ sub to_js ( $self ) {
         $cfg->{alias} = $alias;
     }
 
-    # TODO set type / xtype
-
     my $js = $self->js_call( 'Ext.define', [ "$self->{namespace}->{ext_namespace}.$self->{class_name}", $cfg ] )->to_js;
 
     my $js_gen_cache = $self->{js_gen_cache};
